==> haskell-pointed-5.0.1-66-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-KIoCXYPayza6DD6TiN7soE
key: pointed-5.0.1-KIoCXYPayza6DD6TiN7soE
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
abi: 0635403848e911ab07aaae0be0e3b4ec
exposed: True
exposed-modules:
    Data.Copointed Data.Pointed
import-dirs: /usr/lib/ghc-8.6.3/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-KIoCXYPayza6DD6TiN7soE
depends:
    base-4.12.0.0 comonad-5.0.4-22ADpJgtnGaC808YWN0yOZ
    containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    kan-extensions-5.2-l1qcjAp0Df3lwCeqfEs5H
    semigroupoids-5.3.2-2VNO4X3Idi16ncxsqdERqd stm-2.5.0.0
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.1-67-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-F2Y57vlSLHB1pYRbez8nzw
key: pointed-5.0.1-F2Y57vlSLHB1pYRbez8nzw
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
abi: c0f72c6a9763ad372fd07cdf52d977fe
exposed: True
exposed-modules:
    Data.Copointed Data.Pointed
import-dirs: /usr/lib/ghc-8.6.3/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-F2Y57vlSLHB1pYRbez8nzw
depends:
    base-4.12.0.0 comonad-5.0.4-22ADpJgtnGaC808YWN0yOZ
    containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    kan-extensions-5.2-5qqKdT1Y7BFAuIdw62rW9o
    semigroupoids-5.3.2-2VNO4X3Idi16ncxsqdERqd stm-2.5.0.0
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
